@@ -40,10 +40,7 @@ apply(abs(returnedValues1$holdout - returnedValues1$pred),1,mean,na.rm=TRUE) / m
 plot(returnedValues1)
 
 ## -----------------------------------------------------------------------------
-returnedValues1$holdout
-
-## -----------------------------------------------------------------------------
-returnedValues2 <- ro(x, h=3, origins=8, call=ourCall, value=ourValue, ci=TRUE, co=TRUE)
+returnedValues2 <- ro(x, h=3, origins=8, call=ourCall, value=ourValue, ci=TRUE, co=FALSE)
 
 ## ---- fig.height = 4, fig.width = 6-------------------------------------------
 plot(returnedValues2)
